@@ -1,7 +1,7 @@
 package Config::IOD;
 
 our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,22 +47,6 @@ sub _read_string {
             next LINE;
         }
 
-        # key line
-        if ($line =~ /^(\s*)([^=]+?)(\s*)=
-                      (\s*)(.*?)
-                      (\R?)\z/x) {
-            push @$res, [
-                'K',
-                $1, # COL_K_WS1
-                $2, # COL_K_KEY
-                $3, # COL_K_WS2
-                $4, # COL_K_WS3
-                $5, # COL_K_VALUE_RAW
-                $6, # COL_K_NL
-            ];
-            next LINE;
-        }
-
         # section line
         if ($line =~ /^(\s*)\[(\s*)(.+?)(\s*)\]
                       (?: (\s*)([;#])(.*))?
@@ -109,7 +93,7 @@ sub _read_string {
             }
             my $args = $self->_parse_command_line($6);
             if (!defined($args)) {
-                $self->_err("Invalid arguments syntax '$line'");
+                $self->_err("Invalid arguments syntax '$6'");
             }
             if ($directive eq 'include') {
                 my $path;
@@ -155,6 +139,22 @@ sub _read_string {
             next LINE;
         }
 
+        # key line
+        if ($line =~ /^(\s*)([^=]+?)(\s*)=
+                      (\s*)(.*?)
+                      (\R?)\z/x) {
+            push @$res, [
+                'K',
+                $1, # COL_K_WS1
+                $2, # COL_K_KEY
+                $3, # COL_K_WS2
+                $4, # COL_K_WS3
+                $5, # COL_K_VALUE_RAW
+                $6, # COL_K_NL
+            ];
+            next LINE;
+        }
+
         $self->_err("Invalid syntax");
     }
 
@@ -183,7 +183,7 @@ Config::IOD - Read and write IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.18 of Config::IOD (from Perl distribution Config-IOD), released on 2015-08-18.
+This document describes version 0.19 of Config::IOD (from Perl distribution Config-IOD), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
